
/* =====[ Cb9_.H ]=========================================================

/*
 ************************************************************************
 *
 * DLL CALL HEADER FOR MARX CRYPTO BOX.
 *
 * COPYRIGHT:
 * ----------
 * Copyright (C) MARX Datentechnik GmbH  1994, 1996
 *
 * DISCLAIMER OF WARRANTIES:
 * -------------------------
 *
 * The following [enclosed] code is sample code created by Peter Glen.
 * This sample code is provided to you solely for the purpose of assisting
 * you in the development of your applications.  The code is provided "AS IS",
 * without warranty of any kind.  The author and propriator shall not be
 * liable for any damages arising out of your use of the sample code, even if
 * they have been advised of the possibility of such damages.
 *
 * STATUS: VERSION 1, RELEASE 0, MODIFICATION 0
 *
 ************************************************************************
 *
 * The functions prototyped here, are found in the NTDLL.DLL
 *
 * Further notes:
 * --------------
 *
 * These prototypes are telling the compiler how to use the DLL, and what
 * functions (names) are in it.
 * This is why, this header file is READ ONLY for the end user. If error
 * occurs during compilation, the error cannot be repaired by modifying
 * this header. The error should be repaired in the calling convention etc ...
 *
 * The DLL uses the same calling convention as the WIN API-s, so all
 * compilers should be able to use them.
 *
 * To use this DLL, include IMPORT library (CB9WIN32.LIB) in your project.
 * It contains the all names, and dummy entries, so the linker will
 * think the functions are linked in.
 * In reality, they are resolved at run time, via the DLL mechanism.
 *
 ************************************************************************
 *
 * If you are including this prototype header from C++ environment, tell the
 * compiler that they are all 'C' funtions:
 *
 *        extern "C"
 *        {
 *        #include "Cb9_.h"
 *        }
 *
 * This include file should stop C++ decorated function name generation.
 * Make sure if you use a different compiler, or environment, that the
 * called function names are corresponding with the name declared in this
 * header.
 *
 */

/*
 * Make sure single inclusion:
 */

#ifndef Cb9_defined
#define Cb9_defined

/*
 * The following trick will simplify the export/import of DLL functions.
 *
 * a. No more .def files. Simply include the .lib file, the rest is done
 *    for you.
 *
 * b. The definition EXTERN will be seen by the compiler as:
 *
 *        "__declspec(dllimport)"
 *
 *        So all is done for you, just say:
 *
 *        #include "Cb9_.h"
 *
 * c. If you are working from a C++ environment, tell the compiler
 *        the MARX CRYPTO BOX DLL IS A 'C' DLL BY:
 *
 *        extern "C"
 *        {
 *        #include "Cb9_.h"
 *        }
 *
 */

/* The definition __declspec can be used by Microsoft C++ compiler.
*/
/*#ifdef  MARX_IMPORT
#define EXTERN  __declspec(dllexport)
#else
#define EXTERN __declspec(dllimport)
#endif
*/
#ifdef WIN32BIT
 #ifndef PASCAL
  #define PASCAL
 #endif
 #ifndef FAR
  #define FAR
 #endif

 #define EXTERN
 #define DLLCALL __stdcall   // type WINAPI is defined as __stdcall
#endif

#ifdef WIN16BIT
 #ifndef PASCAL
  #define PASCAL pascal
 #endif
 #define FAR _far

 #define EXTERN extern
 #define DLLCALL FAR PASCAL
#endif


/*
 * The following return codes (and more) may be returned from
 * the CRYPTO BOX:
 * (1. compatibility codes)
 */

#define BAD_COMMAND       1
#define PORT_NOT_FOUND    2
#define BOX_NOT_FOUND     4
#define READ_ERROR        4
#define CHK_0_ERROR       4
#define WRITE_ERROR       8
#define FLUSH_ERROR       8
#define DECREASE_ERROR    8

/*
 * The following return codes (and more) may be returned from
 * the CRYPTO BOX:
 * (2. new NT codes)
 */

#define BOX_OK              0x00
#define BOX_COUNTER_IS_ZERO 0x0A
#define BOX_SEMAFOR_ERROR   0x10
#define BOX_DRIVER_ERROR    0x11
#define BOX_COMM_ERROR      0x12
#define BOX_WHAT_WINDOWS    0x13

/*
 * The following EXTENDED return codes (and more) may be returned from
 * the CRYPTO BOX:
 */

#define     CANNOT_EXECUTE_DDE      0x01
#define     CANNOT_SEND_DDE         0x02
#define     CANNOT_ACCESS_DDE       0x03
#define     CANNOT_REQUEST_DDE      0x04
#define     CANNOT_CONNECT_DDE      0x05
#define     CANNOT_ALLOC_DDE        0x06
#define     CANNOT_STRING_DDE       0x07
#define     CANNOT_INSTANCE_DDE     0x08
#define     CANNOT_DATA_DDE         0x09

#define     VXD_NOT_PRESENT         0x81
#define     VXD_COM_ERROR           0x82
#define     VXD_VER_ERROR           0x83

#define     VDD_NOT_PRESENT         0x84
#define     VDD_COM_ERROR           0x85
#define     VDD_VER_ERROR           0x86
/*
 ************************************************************************
 *
 * Note:    in case of error code values above the listed and defined
 *          values, please call us.
 *
 ************************************************************************
 */

/*
 * The following differences are important:
 * ----------------------------------------
 *
 * The NT library will not use the port number variable, because it
 * communicates with a device driver. The port is actually selected by
 * installing a different device driver for a different port.
 *
 */

/*
 * These are the functions offered by the CRYPTO BOX:
 */

// =======================================================================
// ID functions:
// =======================================================================

EXTERN  short  DLLCALL   Cb9GetID1    (   unsigned short    iPortNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned long   *plIdReturn
                                );

EXTERN  short  DLLCALL   Cb9GetID2      (   unsigned short    iPortNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned long   *plIdReturn
                                );

EXTERN  short  DLLCALL   Cb9GetID3      (   unsigned short    iPortNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned long   *plIdReturn
                                );

EXTERN  short  DLLCALL   Cb9GetID4      (   unsigned short    iPortNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned long   *plIdReturn
                                );

EXTERN  short  DLLCALL   Cb9GetID5      (   unsigned short    iPortNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned long   *plIdReturn
                                );

EXTERN  short  DLLCALL   Cb9GetID6      (   unsigned short    iPortNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned long   *plIdReturn
                                );

EXTERN  short  DLLCALL   Cb9GetSER      (   unsigned short    iPortNr,
                                    unsigned char   *pcSCodeSer,
                                    unsigned long   *plSerNum
                                );

// =======================================================================
// RAM functions:
// =======================================================================


EXTERN short DLLCALL Cb9GetRAM1         (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned char *pcPwReadRam,
                                    unsigned short iStartAdr,
                                    unsigned short uiLength,
                                    unsigned char *pcOutData
                                );
EXTERN short DLLCALL Cb9GetRAM2         (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned char *pcPwReadRam,
                                    unsigned short iStartAdr,
                                    unsigned short uiLength,
                                    unsigned char *pcOutData
                                );
EXTERN short DLLCALL Cb9PutRAM1        (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned char *pcPwReadRam,
                                    unsigned short iStartAdr,
                                    unsigned short uiLength,
                                    unsigned char *pcOutData
                                );
EXTERN short DLLCALL Cb9PutRAM2        (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned char *pcPwReadRam,
                                    unsigned short iStartAdr,
                                    unsigned short uiLength,
                                    unsigned char *pcOutData
                                );

// =======================================================================
// Counter functions:
// =======================================================================


EXTERN short DLLCALL Cb9DecRAM1        (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned short iAdrCount
                                );
EXTERN short DLLCALL Cb9DecRAM2        (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned short iAdrCount
                                );
EXTERN short DLLCALL Cb9Is0RAM1         (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned char *pcPwReadRam,
                                    unsigned short iAdrCount
                                );
EXTERN short DLLCALL Cb9Is0RAM2         (
                                    unsigned short iPortNr,
                                    unsigned short iIdNr,
                                    unsigned char *pcSCodeId,
                                    unsigned char *pcPwReadRam,
                                    unsigned short iAdrCount
                                );

// =======================================================================
// CRYPT functions:
// =======================================================================

EXTERN  short  DLLCALL   Cb9Decrypt     (   unsigned short    iPortNr,
                                    unsigned short    iIdNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned short  iSeed,
                                    unsigned short  iLength,
                                    unsigned char   *pcOutData
                                );

EXTERN  short  DLLCALL   Cb9Encrypt     (   unsigned short    iPortNr,
                                    unsigned short    iIdNr,
                                    unsigned char   *pcSCodeId,
                                    unsigned short  iSeed,
                                    unsigned short  iLength,
                                    unsigned char   *pcOutData
                                );

// =======================================================================
// Misc. functions:
// =======================================================================
EXTERN  short  DLLCALL   Cb9VERSION();


// =======================================================================
// Pointer less functions:
// =======================================================================

EXTERN  short  DLLCALL    CB9_LAST_ERROR      (void);

EXTERN  long   DLLCALL  CB9_R_READID1       (unsigned short   iPortNr, long cSCodeId);
EXTERN  long   DLLCALL  CB9_R_READID2       (unsigned short   iPortNr, long cSCodeId);
EXTERN  long   DLLCALL  CB9_R_READID3       (unsigned short   iPortNr, long cSCodeId);

EXTERN  long   DLLCALL  CB9_R_READID4       (unsigned short   iPortNr, long cSCodeId);
EXTERN  long   DLLCALL  CB9_R_READID5       (unsigned short   iPortNr, long cSCodeId);
EXTERN  long   DLLCALL  CB9_R_READID6       (unsigned short   iPortNr, long cSCodeId);

#endif /* Cb9_defined */

/* EOF */